pub enum Imports<'a> {
Single(usize, Import<'a>),
Compact1 {
module: &'a str,
items: SectionLimited<'a, ImportItemCompact<'a>>,
},
Compact2 {
module: &'a str,
ty: TypeRef,
names: SectionLimited<'a, &'a str>,
},
}Expand description
Represents a group of imports in a WebAssembly module.
Variants
Single(usize, Import<'a>)
The group contains a single import.
Compact1
The group contains many imports that share the same module name, but have different types.
Fields

items: SectionLimited<'a, ImportItemCompact<'a>>The imported items.
Compact2
The group contains many imports that share the same module name and type.