pub trait TypeData: Debug {
type Id: TypeIdentifier<Data = Self>;
const IS_CORE_SUB_TYPE: bool;
}Available on crate feature
validate only.Expand description
A trait shared by all types within a Types.
This is the data that can be retrieved by indexing with the associated
TypeIdentifier.
Required Associated Constants
Sourceconst IS_CORE_SUB_TYPE: bool
const IS_CORE_SUB_TYPE: bool
Is this type a core sub type (or rec group of sub types)?
Required Associated Types
Sourcetype Id: TypeIdentifier<Data = Self>
type Id: TypeIdentifier<Data = Self>
The identifier for this type data.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl TypeData for Range<CoreTypeId>
impl TypeData for Range<CoreTypeId>
const IS_CORE_SUB_TYPE: bool = true
type Id = RecGroupId
Implementors
Sourceimpl TypeData for ComponentDefinedType
Available on crate feature component-model only.
impl TypeData for ComponentDefinedType
Available on crate feature
component-model only.const IS_CORE_SUB_TYPE: bool = false
type Id = ComponentDefinedTypeId
Sourceimpl TypeData for ComponentValType
Available on crate feature component-model only.
impl TypeData for ComponentValType
Available on crate feature
component-model only.const IS_CORE_SUB_TYPE: bool = false
type Id = ComponentValueTypeId
Sourceimpl TypeData for ComponentFuncType
Available on crate feature component-model only.
impl TypeData for ComponentFuncType
Available on crate feature
component-model only.const IS_CORE_SUB_TYPE: bool = false
type Id = ComponentFuncTypeId
Sourceimpl TypeData for ComponentInstanceType
Available on crate feature component-model only.
impl TypeData for ComponentInstanceType
Available on crate feature
component-model only.const IS_CORE_SUB_TYPE: bool = false
type Id = ComponentInstanceTypeId
Sourceimpl TypeData for ComponentType
Available on crate feature component-model only.
impl TypeData for ComponentType
Available on crate feature
component-model only.const IS_CORE_SUB_TYPE: bool = false
type Id = ComponentTypeId
Sourceimpl TypeData for InstanceType
Available on crate feature component-model only.
impl TypeData for InstanceType
Available on crate feature
component-model only.const IS_CORE_SUB_TYPE: bool = false
type Id = ComponentCoreInstanceTypeId
Sourceimpl TypeData for ModuleType
Available on crate feature component-model only.
impl TypeData for ModuleType
Available on crate feature
component-model only.